@@ -127,6 +127,10 @@ class HostedBackend(Backend):
             pass
         else:
             raise MissingApiTokenException()
+        if os.getenv(envs.API_MODEL):
+            self.set_app(os.getenv(envs.API_MODEL))
+        if os.getenv(envs.API_PROJ):
+            self.set_model(os.getenv(envs.API_PROJ))
         from waveletai import __version__
         self.client_lib_version = __version__
         self._session = requests.session()
