@@ -32,28 +32,28 @@ class Model(object):
         self.update_time = update_time
         self.update_user_id = update_user_id
 
-    def update(self, app_id, name, desc):
+    def update(self, name, desc):
         """
         更新模型信息
         :return: class: `Model` Object
         """
-        return self._backend.update_model(self.id, app_id, name, desc)
+        return self._backend.update_model(name, desc)
 
     def delete(self):
         """
         删除模型
         :return:
         """
-        return self._backend.delete_model(self.id)
+        return self._backend.delete_model()
 
-    def register_model_version(self, path, desc, mode=ModelRegisterMode.PYFUNC.value):
+    def register_model_version(self, desc, path, mode=ModelRegisterMode.PYFUNC.value):
         """
         注册模型库版本
         :param mode: 注册模式,默认为自定义
         :param path: 注册文件路径，可以是文件夹,当为docker模式时，此处为docker-image,可以用save命令导出  eg：deployment.tar
         :return: class: `ModelVersion` Object
         """
-        self._backend.register_model_version(self.id, desc, path, mode)
+        self._backend.register_model_version(desc, path, mode)
 
     def get_model_version(self, version):
         """
@@ -61,7 +61,7 @@ class Model(object):
         :param version: 模型版本号，如1,2,3
         :return: class: `ModelVersion` Object
         """
-        return self._backend.get_model_version(self.id, version)
+        return self._backend.get_model_version(version)
 
     def list_model_versions(self):
         """
@@ -78,7 +78,7 @@ class Model(object):
         :param desc: 模型版本信息
         :return:  List of Class `ModelVersion` Object
         """
-        return self._backend.update_model_version(self.id, version, desc)
+        return self._backend.update_model_version(version, desc)
 
     def abandon_model_version(self, version):
         """
@@ -86,21 +86,21 @@ class Model(object):
         :param version: 模型版本号，如1,2,3
         :return:
         """
-        return self._backend.abandon_model_version(self.id, version)
+        return self._backend.abandon_model_version(version)
 
     def list_experiments(self):
         """
         返回当前模型的实验列表
         :return: List of Class `Experiment` Object
         """
-        return self._backend.list_experiments(self.id)
+        return self._backend.list_experiments()
 
     def list_release(self, version=None):
         """
         返回当前模型的发布列表，version为空时返回所有
         :return: List of Class `Release` Object
         """
-        return self._backend.list_model_releases(self.id, version)
+        return self._backend.list_model_releases(version)
 
     def search_model_versions(self, desc, stage):
         """search for a specific stage or desc and list its version details"""
@@ -109,10 +109,6 @@ class Model(object):
     def transition_model_version_stage(self, version, stage):
         pass
 
-    def search_model_versions(self, desc, stage):
-        """search for a specific stage or desc and list its version details"""
-        pass
-
     def mlflow_project_file(self, mlproject_path=None):
         """
         获取模型的MLProject
@@ -124,7 +120,7 @@ class Model(object):
             with open(mlproject_path, 'rb') as f:
                 return yaml.load(f, Loader=yaml.FullLoader)
 
-        return self._backend.get_mlproject_file(self.id)
+        return self._backend.get_mlproject_file()
 
     @set_mlflow_tracing_waveletai_store
     def create_experiment(self, name, params=None):
@@ -218,4 +214,4 @@ class ModelVersion(object):
         查询当前模型版本的发布服务列表
         :return:
         """
-        return self._backend.list_model_releases_by_repo(self.id)
+        return self._backend.list_model_releases_by_repo()
